import { DocNodeKind, DocNode } from './DocNode';
import { DocDeclarationReference } from './DocDeclarationReference';
import { DocInlineTagBase, IDocInlineTagBaseParsedParameters, IDocInlineTagBaseParameters } from './DocInlineTagBase';
import { TokenSequence } from '../parser/TokenSequence';
/**
 * Constructor parameters for {@link DocLinkTag}.
 */
export interface IDocLinkTagParameters extends IDocInlineTagBaseParameters {
    codeDestination?: DocDeclarationReference;
    urlDestination?: string;
    linkText?: string;
}
/**
 * Constructor parameters for {@link DocLinkTag}.
 */
export interface IDocLinkTagParsedParameters extends IDocInlineTagBaseParsedParameters {
    codeDestination?: DocDeclarationReference;
    urlDestinationExcerpt?: TokenSequence;
    spacingAfterDestinationExcerpt?: TokenSequence;
    pipeExcerpt?: TokenSequence;
    linkTextExcerpt?: TokenSequence;
}
/**
 * Represents an `{@link}` tag.
 */
export declare class DocLinkTag extends DocInlineTagBase {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private readonly _codeDestination;
    private _urlDestination;
    private readonly _urlDestinationExcerpt;
    private readonly _spacingAfterDestinationExcerpt;
    private readonly _pipeExcerpt;
    private _linkText;
    private readonly _linkTextExcerpt;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocLinkTagParameters | IDocLinkTagParsedParameters);
    /**
     * If the link tag refers to a declaration, this returns the declaration reference object;
     * otherwise this property is undefined.
     * @remarks
     * Either the `codeDestination` or the `urlDestination` property will be defined, but never both.
     */
    readonly codeDestination: DocDeclarationReference | undefined;
    /**
     * If the link tag was an ordinary URI, this returns the URL string;
     * otherwise this property is undefined.
     * @remarks
     * Either the `codeDestination` or the `urlDestination` property will be defined, but never both.
     */
    readonly urlDestination: string | undefined;
    /**
     * An optional text string that is the hyperlink text.  If omitted, the documentation
     * renderer will use a default string based on the link itself (e.g. the URL text
     * or the declaration identifier).
     */
    readonly linkText: string | undefined;
    /** @override */
    protected getChildNodesForContent(): ReadonlyArray<DocNode | undefined>;
}
