import { DocNodeKind, DocNode } from './DocNode';
import { DocBlock, IDocBlockParameters, IDocBlockParsedParameters } from './DocBlock';
import { TokenSequence } from '../parser/TokenSequence';
/**
 * Constructor parameters for {@link DocParamBlock}.
 */
export interface IDocParamBlockParameters extends IDocBlockParameters {
    parameterName: string;
}
/**
 * Constructor parameters for {@link DocParamBlock}.
 */
export interface IDocParamBlockParsedParameters extends IDocBlockParsedParameters {
    spacingBeforeParameterNameExcerpt?: TokenSequence;
    parameterNameExcerpt: TokenSequence;
    parameterName: string;
    spacingAfterParameterNameExcerpt?: TokenSequence;
    hyphenExcerpt: TokenSequence;
    spacingAfterHyphenExcerpt?: TokenSequence;
}
/**
 * Represents a parsed `@param` or `@typeParam` block, which provides a description for a
 * function parameter.
 */
export declare class DocParamBlock extends DocBlock {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private readonly _spacingBeforeParameterNameExcerpt;
    private readonly _parameterName;
    private readonly _parameterNameExcerpt;
    private readonly _spacingAfterParameterNameExcerpt;
    private readonly _hyphenExcerpt;
    private readonly _spacingAfterHyphenExcerpt;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocParamBlockParameters | IDocParamBlockParsedParameters);
    /**
     * The name of the parameter that is being documented.
     * For example "width" in `@param width - the width of the object`.
     */
    readonly parameterName: string;
    /** @override */
    protected onGetChildNodes(): ReadonlyArray<DocNode | undefined>;
}
